==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/IdentitySourceUserProfileForDelete.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentitySourceUserProfileForDelete
 */
@JsonPropertyOrder({ IdentitySourceUserProfileForDelete.JSON_PROPERTY_EXTERNAL_ID })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdentitySourceUserProfileForDelete implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXTERNAL_ID = "externalId";
    private String externalId;

    public IdentitySourceUserProfileForDelete() {
    }

    public IdentitySourceUserProfileForDelete externalId(String externalId) {

        this.externalId = externalId;
        return this;
    }

    /**
     * The external ID of the entity that needs to be deleted in Okta
     *
     * @return externalId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The external ID of the entity that needs to be deleted in Okta")
    @JsonProperty(JSON_PROPERTY_EXTERNAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getExternalId() {
        return externalId;
    }

    @JsonProperty(JSON_PROPERTY_EXTERNAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExternalId(String externalId) {
        this.externalId = externalId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentitySourceUserProfileForDelete identitySourceUserProfileForDelete = (IdentitySourceUserProfileForDelete) o;
        return Objects.equals(this.externalId, identitySourceUserProfileForDelete.externalId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(externalId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentitySourceUserProfileForDelete {\n");
        sb.append("    externalId: ").append(toIndentedString(externalId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/IdentitySourceUserProfileForDelete.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentitySourceUserProfileForDelete
 */
@JsonPropertyOrder({ IdentitySourceUserProfileForDelete.JSON_PROPERTY_EXTERNAL_ID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdentitySourceUserProfileForDelete implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXTERNAL_ID = "externalId";
    private String externalId;

    public IdentitySourceUserProfileForDelete() {
    }

    public IdentitySourceUserProfileForDelete externalId(String externalId) {

        this.externalId = externalId;
        return this;
    }

    /**
     * The external ID of the entity that needs to be deleted in Okta
     *
     * @return externalId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The external ID of the entity that needs to be deleted in Okta")
    @JsonProperty(JSON_PROPERTY_EXTERNAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getExternalId() {
        return externalId;
    }

    @JsonProperty(JSON_PROPERTY_EXTERNAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExternalId(String externalId) {
        this.externalId = externalId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentitySourceUserProfileForDelete identitySourceUserProfileForDelete = (IdentitySourceUserProfileForDelete) o;
        return Objects.equals(this.externalId, identitySourceUserProfileForDelete.externalId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(externalId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentitySourceUserProfileForDelete {\n");
        sb.append("    externalId: ").append(toIndentedString(externalId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
